package com.jasamedika.medifirst2000.service;

import java.util.List;
import java.util.Map;

import com.jasamedika.medifirst2000.dto.AlatDto;
import com.jasamedika.medifirst2000.entities.Alat;
import com.jasamedika.medifirst2000.vo.AlatVO;

public interface AlatService <T> extends BaseVoService<Alat, AlatVO, Integer> {

	Map<String, Object> addAlat(AlatVO vo);

	Map<String, Object> updateAlat(AlatVO vo);

	Map<String, Object> findAllAlat();

	boolean deleteAlat(Integer id);

	List<Map<String,Object>> getAllProdukAset();
	
	List<Map<String,Object>> getAllSatuanStandar();
	
	Map<String, Object> getDepartemenLaundry();

	Map<String, Object> saveAlat(AlatDto vo);

	Map<String, Object> getByAlatId(Integer alatId);

	List<Map<String,Object>> getAllAlat();
	
	Map<String,Object> getMaxId();
	
	Map<String, Object> cekMesiId(Integer produkAsetId,Integer alatId);
	
	Map<String, Object> findAssetLaundry();
	Map<String, Object> getMesinLaundry();

}
